==> qtjambi-test-debuginfo-macos-5.15.18.jar: sources/QtJambiTest/QSpontaneKeyEvent_shell.cpp <==
#include "QSpontaneKeyEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QSpontaneKeyEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSpontaneKeyEvent")
    QSpontaneKeyEvent *_ptr = reinterpret_cast<QSpontaneKeyEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSpontaneKeyEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSpontaneKeyEvent_shell) ); }

jmethodID QSpontaneKeyEvent_shell::__shell_javaMethod(int pos) const { return QSpontaneKeyEvent_shell::__shell()->javaMethod(typeid(QSpontaneKeyEvent), pos); }

// emitting (writeShellConstructor)
QSpontaneKeyEvent_shell::QSpontaneKeyEvent_shell()
    : QSpontaneKeyEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSpontaneKeyEvent::QSpontaneKeyEvent_shell()", QSpontaneKeyEvent_shell::__shell())
    QSpontaneKeyEvent_shell::__shell()->constructed(typeid(QSpontaneKeyEvent));
}

// emitting (writeShellDestructor)
QSpontaneKeyEvent_shell::~QSpontaneKeyEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSpontaneKeyEvent::~QSpontaneKeyEvent()", QSpontaneKeyEvent_shell::__shell())
    QSpontaneKeyEvent_shell::__shell()->destructed(typeid(QSpontaneKeyEvent));
}

void QSpontaneKeyEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSpontaneKeyEvent_shell*>(ptr)->QSpontaneKeyEvent_shell::__shell()->tryDeleteShell(typeid(QSpontaneKeyEvent));
}

// emitting Virtual overrides (virtualFunctions)
void QSpontaneKeyEvent_shell::dummyFunc()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSpontaneKeyEvent::dummyFunc()", QSpontaneKeyEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSpontaneKeyEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSpontaneKeyEvent_shell::__shell()->warnForMethod("QSpontaneKeyEvent::dummyFunc()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSpontaneKeyEvent::dummyFunc()");
            } QTJAMBI_TRY_END
        }else{
            QSpontaneKeyEvent::dummyFunc();
        }
    }else{
        QSpontaneKeyEvent::dummyFunc();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QSpontaneKeyEvent_access::__qt_dummyFunc(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QSpontaneKeyEvent::dummyFunc();
    } else {
        dummyFunc();
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QSpontaneKeyEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QSpontaneKeyEvent *__qt_this = new(__qtjambi_ptr) QSpontaneKeyEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QSpontaneKeyEvent_shell
void __qt_destruct_QSpontaneKeyEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSpontaneKeyEvent")
    reinterpret_cast<QSpontaneKeyEvent_shell*>(ptr)->~QSpontaneKeyEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSpontaneKeyEvent::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_initialize_1native__Lio_qt_test_QSpontaneKeyEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSpontaneKeyEvent::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSpontaneKeyEvent_0, sizeof(QSpontaneKeyEvent_shell), typeid(QSpontaneKeyEvent), true, &deleter_QSpontaneKeyEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSpontaneKeyEvent::ifYouGetCompileErrorHereYouUseWrongQt()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_ifYouGetCompileErrorHereYouUseWrongQt_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSpontaneKeyEvent::ifYouGetCompileErrorHereYouUseWrongQt()", __qt_this)
        __qt_this->ifYouGetCompileErrorHereYouUseWrongQt();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSpontaneKeyEvent::setSpontaneous()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_setSpontaneous_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSpontaneKeyEvent::setSpontaneous()", __qt_this)
        __qt_this->setSpontaneous();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSpontaneKeyEvent::spontaneous()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_spontaneous_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSpontaneKeyEvent::spontaneous()", __qt_this)
        __java_return_value = __qt_this->spontaneous();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSpontaneKeyEvent::dummyFunc()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_dummyFunc_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSpontaneKeyEvent::dummyFunc()", __qt_this)
        static_cast<QSpontaneKeyEvent_access*>(__qt_this)->__qt_dummyFunc(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSpontaneKeyEvent::setSpontaneous(QEvent*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_setSpontaneous_1native_1QEvent_1ptr__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID ev0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSpontaneKeyEvent::setSpontaneous(QEvent*)")
    QTJAMBI_TRY {
        QEvent* __qt_ev0 = QtJambiAPI::objectFromNativeId<QEvent>(ev0);
        QSpontaneKeyEvent::setSpontaneous(__qt_ev0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSpontaneKeyEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSpontaneKeyEvent>("QSpontaneKeyEvent", "io/qt/test/QSpontaneKeyEvent");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "dummyFunc", "()V")});
    registerConstructorInfos(typeId, &__qt_destruct_QSpontaneKeyEvent, {
        ConstructorInfo(&__qt_construct_QSpontaneKeyEvent_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSpontaneKeyEvent);
    registerMetaType<QSpontaneKeyEvent>("QSpontaneKeyEvent");
    registerSizeOfShell(typeId, sizeof(QSpontaneKeyEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-test-debuginfo-macos-5.15.20.jar: sources/QtJambiTest/QSpontaneKeyEvent_shell.cpp <==
#include "QSpontaneKeyEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QSpontaneKeyEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSpontaneKeyEvent")
    QSpontaneKeyEvent *_ptr = reinterpret_cast<QSpontaneKeyEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSpontaneKeyEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSpontaneKeyEvent_shell) ); }

jmethodID QSpontaneKeyEvent_shell::__shell_javaMethod(int pos) const { return QSpontaneKeyEvent_shell::__shell()->javaMethod(typeid(QSpontaneKeyEvent), pos); }

// emitting (writeShellConstructor)
QSpontaneKeyEvent_shell::QSpontaneKeyEvent_shell()
    : QSpontaneKeyEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSpontaneKeyEvent::QSpontaneKeyEvent_shell()", QSpontaneKeyEvent_shell::__shell())
    QSpontaneKeyEvent_shell::__shell()->constructed(typeid(QSpontaneKeyEvent));
}

QSpontaneKeyEvent_shell::QSpontaneKeyEvent_shell(const QSpontaneKeyEvent& other0)
    : QSpontaneKeyEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSpontaneKeyEvent::QSpontaneKeyEvent_shell(const QSpontaneKeyEvent& other0)", QSpontaneKeyEvent_shell::__shell())
    QSpontaneKeyEvent_shell::__shell()->constructed(typeid(QSpontaneKeyEvent));
}

// emitting (writeShellDestructor)
QSpontaneKeyEvent_shell::~QSpontaneKeyEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSpontaneKeyEvent::~QSpontaneKeyEvent()", QSpontaneKeyEvent_shell::__shell())
    QSpontaneKeyEvent_shell::__shell()->destructed(typeid(QSpontaneKeyEvent));
}

void QSpontaneKeyEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSpontaneKeyEvent_shell*>(ptr)->QSpontaneKeyEvent_shell::__shell()->tryDeleteShell(typeid(QSpontaneKeyEvent));
}

// emitting Virtual overrides (virtualFunctions)
void QSpontaneKeyEvent_shell::dummyFunc()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSpontaneKeyEvent::dummyFunc()", QSpontaneKeyEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSpontaneKeyEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSpontaneKeyEvent_shell::__shell()->warnForMethod("QSpontaneKeyEvent::dummyFunc()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSpontaneKeyEvent::dummyFunc()");
            } QTJAMBI_TRY_END
        }else{
            QSpontaneKeyEvent::dummyFunc();
        }
    }else{
        QSpontaneKeyEvent::dummyFunc();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QSpontaneKeyEvent_access::__qt_dummyFunc(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QSpontaneKeyEvent::dummyFunc();
    } else {
        dummyFunc();
    }
}

// emitting (writeConstructors)
// new QSpontaneKeyEvent()
void __qt_construct_QSpontaneKeyEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSpontaneKeyEvent()")
    Q_UNUSED(__java_arguments)
    QSpontaneKeyEvent *__qt_this = new(__qtjambi_ptr) QSpontaneKeyEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QSpontaneKeyEvent::QSpontaneKeyEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_initialize_1native__Lio_qt_test_QSpontaneKeyEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSpontaneKeyEvent::QSpontaneKeyEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSpontaneKeyEvent, sizeof(QSpontaneKeyEvent_shell), typeid(QSpontaneKeyEvent), true, &deleter_QSpontaneKeyEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QSpontaneKeyEvent(QSpontaneKeyEvent)
void __qt_construct_QSpontaneKeyEvent_cref_QSpontaneKeyEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSpontaneKeyEvent(QSpontaneKeyEvent)")
    jobject other0 = __java_arguments[0].l;
    const QSpontaneKeyEvent& __qt_other0 = qtjambi_cast<const QSpontaneKeyEvent& >(__jni_env, other0);
    QSpontaneKeyEvent *__qt_this = new(__qtjambi_ptr) QSpontaneKeyEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QSpontaneKeyEvent::QSpontaneKeyEvent(QSpontaneKeyEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_initialize_1native__Lio_qt_test_QSpontaneKeyEvent_2Lio_qt_test_QSpontaneKeyEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSpontaneKeyEvent::QSpontaneKeyEvent(QSpontaneKeyEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSpontaneKeyEvent_cref_QSpontaneKeyEvent, sizeof(QSpontaneKeyEvent_shell), typeid(QSpontaneKeyEvent), true, &deleter_QSpontaneKeyEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSpontaneKeyEvent_shell
void __qt_destruct_QSpontaneKeyEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSpontaneKeyEvent")
    reinterpret_cast<QSpontaneKeyEvent_shell*>(ptr)->~QSpontaneKeyEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSpontaneKeyEvent::ifYouGetCompileErrorHereYouUseWrongQt()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_ifYouGetCompileErrorHereYouUseWrongQt_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSpontaneKeyEvent::ifYouGetCompileErrorHereYouUseWrongQt()", __qt_this)
        __qt_this->ifYouGetCompileErrorHereYouUseWrongQt();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSpontaneKeyEvent::setSpontaneous()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_setSpontaneous_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSpontaneKeyEvent::setSpontaneous()", __qt_this)
        __qt_this->setSpontaneous();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSpontaneKeyEvent::spontaneous()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_spontaneous_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSpontaneKeyEvent::spontaneous()", __qt_this)
        __java_return_value = __qt_this->spontaneous();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSpontaneKeyEvent::dummyFunc()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_dummyFunc_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSpontaneKeyEvent::dummyFunc()", __qt_this)
        static_cast<QSpontaneKeyEvent_access*>(__qt_this)->__qt_dummyFunc(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSpontaneKeyEvent::setSpontaneous(QEvent*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_setSpontaneous_1native_1QEvent_1ptr__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID ev0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSpontaneKeyEvent::setSpontaneous(QEvent*)")
    QTJAMBI_TRY {
        QEvent* __qt_ev0 = QtJambiAPI::objectFromNativeId<QEvent>(ev0);
        QSpontaneKeyEvent::setSpontaneous(__qt_ev0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QSpontaneKeyEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSpontaneKeyEvent *__qt_this = QtJambiAPI::objectFromNativeId<QSpontaneKeyEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSpontaneKeyEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSpontaneKeyEvent>("QSpontaneKeyEvent", "io/qt/test/QSpontaneKeyEvent");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "dummyFunc", "()V")});
    registerConstructorInfos(typeId, &__qt_destruct_QSpontaneKeyEvent, {
        ConstructorInfo(&__qt_construct_QSpontaneKeyEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QSpontaneKeyEvent_cref_QSpontaneKeyEvent, "Lio/qt/test/QSpontaneKeyEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSpontaneKeyEvent);
    registerMetaType<QSpontaneKeyEvent>("QSpontaneKeyEvent");
    registerSizeOfShell(typeId, sizeof(QSpontaneKeyEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
